@@ -39,7 +39,6 @@
 
 #include "cc-common-language.h"
 #include "cc-util.h"
-#include "cc-ibus-utils.h"
 
 #include <glib-object.h>
 
@@ -203,9 +202,15 @@ input_widget_new (CcInputChooser *chooser,
 
 	if (g_str_equal (type, INPUT_SOURCE_TYPE_XKB)) {
 		gnome_xkb_info_get_layout_info (priv->xkb_info, id, &name, NULL, NULL, NULL);
-	} else if (g_str_equal (type, INPUT_SOURCE_TYPE_IBUS)) {
-		name = engine_get_display_name (g_hash_table_lookup (priv->ibus_engines, id));
 	}
+#ifdef HAVE_IBUS
+        else if (g_str_equal (type, INPUT_SOURCE_TYPE_IBUS)) {
+                if (priv->ibus_engines)
+                        name = engine_get_display_name (g_hash_table_lookup (priv->ibus_engines, id));
+                else
+                        name = id;
+	}
+#endif
 	else {
 		name = "ERROR";
 	}
@@ -223,6 +228,8 @@ input_widget_new (CcInputChooser *chooser,
 	gtk_widget_set_margin_end (widget->box, 10);
 	widget->label = gtk_label_new (name);
 	gtk_misc_set_alignment (GTK_MISC (widget->label), 0, 0.5);
+        gtk_label_set_ellipsize (GTK_LABEL (widget->label), PANGO_ELLIPSIZE_END);
+        gtk_label_set_max_width_chars (GTK_LABEL (widget->label), 40);
 	gtk_label_set_width_chars (GTK_LABEL (widget->label), 40);
 	gtk_box_pack_start (GTK_BOX (widget->box), widget->label, FALSE, FALSE, 0);
 	widget->checkmark = gtk_image_new_from_icon_name ("object-select-symbolic", GTK_ICON_SIZE_MENU);
@@ -365,9 +372,8 @@ get_locale_infos (CcInputChooser *chooser)
 	gchar *lang, *country;
 	GList *list;
 
-	if (gnome_get_input_source_from_locale (priv->locale, &type, &id)) { 
-		if (g_str_equal (type, INPUT_SOURCE_TYPE_XKB))
-			add_row_to_list (chooser, type, id);
+	if (gnome_get_input_source_from_locale (priv->locale, &type, &id)) {
+                add_row_to_list (chooser, type, id);
 		if (!priv->id) {
 			priv->id = g_strdup (id);
 			priv->type = g_strdup (type);
@@ -591,34 +597,13 @@ get_ibus_locale_infos (CcInputChooser *chooser)
 	GHashTableIter iter;
 	const gchar *engine_id;
 	IBusEngineDesc *engine;
-	gchar *lang, *country;
 
 	if (!priv->ibus_engines)
 		return;
 
-	if (!gnome_parse_locale (priv->locale, &lang, &country, NULL, NULL))
-		goto out;
-
 	g_hash_table_iter_init (&iter, priv->ibus_engines);
-	while (g_hash_table_iter_next (&iter, (gpointer *) &engine_id, (gpointer *) &engine)) {
-		gchar *ibus_lang = NULL;
-		gchar *ibus_country = NULL;
-		const gchar *locale;
-
-		locale = ibus_engine_desc_get_language (engine);
-
-		if (gnome_parse_locale (locale, &ibus_lang, &ibus_country, NULL, NULL)) {
-			if (g_strcmp0 (lang, ibus_lang) == 0 &&
-			    (ibus_country == NULL || g_strcmp0 (country, ibus_country) == 0))
-				add_row_to_list (chooser, INPUT_SOURCE_TYPE_IBUS, engine_id);
-		}
-		g_free (ibus_lang);
-		g_free (ibus_country);
-        }
-
-out:
-	g_free (lang);
-	g_free (country);
+	while (g_hash_table_iter_next (&iter, (gpointer *) &engine_id, (gpointer *) &engine))
+                add_row_to_list (chooser, INPUT_SOURCE_TYPE_IBUS, engine_id);
 }
 
 static void
@@ -659,7 +644,6 @@ fetch_ibus_engines_result (GObject       *object,
 
         sync_all_checkmarks (chooser);
 }
-#endif
 
 static void
 fetch_ibus_engines (CcInputChooser *chooser)
@@ -693,6 +677,7 @@ maybe_start_ibus (void)
                                               NULL,
                                               NULL));
 }
+#endif
 
 static void
 cc_input_chooser_constructed (GObject *object)
@@ -749,9 +734,6 @@ cc_input_chooser_constructed (GObject *object)
         g_signal_connect (priv->input_list, "row-activated",
                           G_CALLBACK (row_activated), chooser);
 
-        if (priv->locale == NULL)
-                priv->locale = cc_common_language_get_current_language ();
-
         sync_all_checkmarks (chooser);
 }
 
